package com.example.rabbitmq.listener;

import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.ExchangeTypes;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.stereotype.Component;

@Slf4j
@Component
public class MqListener {
    /**
     * 监听
     *
     * @param message 收到消息
     */
    @RabbitListener(queues = "hello.eq")
    void listenHelloQueue(String message) {
        System.out.println("消费者[hello.eq]收到了消息" + message);
    }

    /**
     * 监听 work.queue 中队列消息
     *
     * @param message 消息
     */
    @RabbitListener(queues = "work.queue")
    void workQueue(String message) {
        System.out.println("消费者[work.queue]收到消息" + message);
    }

    /**
     * 监听 work.queue 中队列消息
     *
     * @param message 消息
     */
    @RabbitListener(queues = "work.queue")
    void workQueue2(String message) {
        System.err.println("消费者2[work.queue]收到消息" + message);
    }

    /**
     * 监听 direct.queue1 中队列消息
     *
     * @param message 消息
     */
    @RabbitListener(queues = "direct.queue1")
    public void listenDirectQueue1(String message) {
        System.out.println("direct.queue1 收到了 direct.queue1：【消息】" + message);
    }

    @RabbitListener(queues = "object.queue")
    public void listenObjectQueue(String message) {
        System.out.println("object.queue 收到了 object.queue：【消息】" + message);
    }

    /**
     * 监听 direct.queue2 中队列消息
     *
     * @param message 消息
     */
    @RabbitListener(queues = "direct.queue2")
    public void listenDirectQueue(String message) {
        System.out.println("direct.queue2 收到了 direct.queue2：【消息】" + message);
    }

    /**
     * 接受消息 topic.queue1
     *
     * @param message 消息
     */
    @RabbitListener(bindings = @QueueBinding(
            value = @Queue(name = "topic.queue1", durable = "true"),
            exchange = @Exchange(name = "bunny.direct", type = ExchangeTypes.DIRECT),
            key = {"red", "blue"}
    ))
    public void listenTopicQueue1(String message) {
        System.out.println("topic.queue1 收到了 【消息]" + message);
    }

    /**
     * 接受消息 topic.queue1
     *
     * @param message 消息
     */
    @RabbitListener(bindings = @QueueBinding(
            value = @Queue(name = "topic.queue2", durable = "true"),
            exchange = @Exchange(name = "bunny.direct", type = ExchangeTypes.DIRECT),
            key = {"yellow", "red"}
    ))
    public void listenTopicQueue2(String message) {
        System.out.println("topic.queue2 收到了 【消息]" + message);
    }

    /**
     * 监听延迟队列
     * @param message 消息
     */
    @RabbitListener(bindings = @QueueBinding(
            value = @Queue(value = "delay.queue", durable = "true"),
            exchange = @Exchange(value = "delay.direct", delayed = "true"),
            key = "hi"
    ))
    public void listenDelayLazyQueue(String message) {
        log.info("接收到 lazy.queue消息：{}", message);
    }
}
