package com.example.rabbitmq;

import org.junit.jupiter.api.Test;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

@SpringBootTest
class RabbitMqApplicationTests {
    @Autowired
    private RabbitTemplate rabbitTemplate;

    /**
     * 消息发送
     * 不是阻塞的，当有消息进来时可以监听到
     */
    @Test
    void contextLoads() {
        String queueName = "hello.eq";
        String message = "Hello";
        rabbitTemplate.convertAndSend(queueName, message);
    }

    // 接受消息
    @Test
    void testWorkQueue() throws InterruptedException {
        for (int i = 1; i <= 100; i++) {
            String queueName = "work.queue";
            String message = "Hello" + i;
            rabbitTemplate.convertAndSend(queueName, message);
            Thread.sleep(20);
        }
    }

    // 发给交换机，使用key发送，当前key是所有人都可以接受到
    @Test
    void testWorkQueue1() {
        String exchangeName = "bunny.direct";
        String message = "所有人都收到";
        rabbitTemplate.convertAndSend(exchangeName, "red", message);
    }

    // 发送消息固定key可以接受到
    @Test
    void testWorkQueue2() {
        String exchangeName = "bunny.direct";
        String message = "blue都收到";
        rabbitTemplate.convertAndSend(exchangeName, "blue", message);
    }

    // 使用通配符 chin.# 后面无论写什么这个都能收到，topic可以接受通配符
    @Test
    void testWorkQueue3() {
        String exchangeName = "bunny.topic";
        String message = "今天天气好";
        rabbitTemplate.convertAndSend(exchangeName, "chin.weather", message);
    }
}
