package com.example.rabbitmq;

import org.junit.jupiter.api.Test;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.core.MessageBuilder;
import org.springframework.amqp.core.MessageDeliveryMode;
import org.springframework.amqp.core.ReturnedMessage;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.context.annotation.Bean;
import org.springframework.util.concurrent.ListenableFutureCallback;

import java.nio.charset.StandardCharsets;
import java.util.*;

@SpringBootTest
public class SendMessageTest {
    @Autowired
    private RabbitTemplate rabbitTemplate;

    // 声明使用JSON，否咋在消息队列中会有很长一段字符串
    @Test
    void testSendObject() {
        Map<String, Object> map = new HashMap<>(2);
        map.put("name", "test");
        map.put("age", 21);
        rabbitTemplate.convertAndSend("object.queue", map);
    }

    // 版本改动，没有找到callback函数----作废----
    @Test
    void sendConfirmCallback() {
        CorrelationData data = new CorrelationData(UUID.randomUUID().toString());
        data.getFuture();
        rabbitTemplate.convertAndSend("bunny.direct", "red", "hello", data);
    }

    /**
     * 消息的持久化
     */
    @Test
    void testPageOut() {
        Message message = MessageBuilder
                .withBody("Hello".getBytes(StandardCharsets.UTF_8))
                // .setDeliveryMode(MessageDeliveryMode.NON_PERSISTENT).build();
                .setDeliveryMode(MessageDeliveryMode.PERSISTENT).build();// 消息的持久化

        for (int i = 0; i < 9000000; i++) {
            rabbitTemplate.convertAndSend("object.queue", message);
        }
    }
}
